@@ -1,8 +1,6 @@
-#from itertools import chain
 import sqlalchemy as sa
-#from sqlalchemy_utils.functions import primary_keys
 from .operation import Operation
-from .utils import versioned_column_properties
+from .utils import versioned_column_properties, parent_class
 
 
 def first_level(paths):
@@ -26,8 +24,8 @@ class Reverter(object):
         self.visited_objects = visited_objects
         self.obj = obj
         self.version_parent = self.obj.version_parent
-        self.parent_class = self.obj.__parent_class__
-        self.parent_mapper = sa.inspect(self.obj.__parent_class__)
+        self.parent_class = parent_class(self.obj.__class__)
+        self.parent_mapper = sa.inspect(self.parent_class)
 
         self.relations = list(relations)
         for path in relations:
@@ -36,7 +34,7 @@ class Reverter(object):
                 raise ReverterException(
                     "Could not initialize Reverter. Class '%s' does not have "
                     "relationship '%s'." % (
-                        self.obj.__parent_class__.__name__,
+                        parent_class(self.obj.__class__).__name__,
                         subpath
                     )
                 )
@@ -49,6 +47,41 @@ class Reverter(object):
                 getattr(self.obj, prop.key)
             )
 
+    def revert_association(self, prop):
+        if prop.uselist:
+            setattr(self.version_parent, prop.key, [])
+            for child_obj in getattr(self.obj, prop.key):
+                value = self.revert_child(child_obj, prop)
+                if value:
+                    getattr(self.version_parent, prop.key).append(
+                        value
+                    )
+        else:
+            setattr(self.version_parent, prop.key, None)
+            value = getattr(self.obj, prop.key)
+            value = self.revert_child(
+                value, prop
+            )
+            if value:
+                setattr(self.version_parent, prop.key, value)
+
+    def revert_relationship(self, prop):
+        if prop.secondary is not None:
+            self.revert_association(prop)
+        else:
+            if prop.uselist:
+                for value in getattr(self.obj, prop.key):
+                    self.revert_child(value, prop)
+            else:
+                self.revert_child(getattr(self.obj, prop.key), prop)
+
+    def revert_child(self, child, prop):
+        return self.__class__(
+            child,
+            visited_objects=self.visited_objects,
+            relations=subpaths(self.relations, prop.key)
+        )()
+
     def revert_relationships(self):
         for prop in self.parent_mapper.iterate_properties:
             if isinstance(prop, sa.orm.RelationshipProperty):
@@ -58,25 +91,7 @@ class Reverter(object):
                 if prop.key not in first_level(self.relations):
                     continue
 
-                if prop.secondary is not None:
-                    setattr(self.version_parent, prop.key, [])
-                    for value in getattr(self.obj, prop.key):
-                        value = Reverter(
-                            value,
-                            visited_objects=self.visited_objects,
-                            relations=subpaths(self.relations, prop.key)
-                        )()
-                        if value:
-                            getattr(self.version_parent, prop.key).append(
-                                value
-                            )
-                else:
-                    for value in getattr(self.obj, prop.key):
-                        Reverter(
-                            value,
-                            visited_objects=self.visited_objects,
-                            relations=subpaths(self.relations, prop.key)
-                        )()
+                self.revert_relationship(prop)
 
     def __call__(self):
         if self.obj in self.visited_objects:
@@ -92,7 +107,7 @@ class Reverter(object):
 
         # Check if parent object has been deleted
         if self.version_parent is None:
-            self.version_parent = self.obj.__parent_class__()
+            self.version_parent = parent_class(self.obj.__class__)()
             session.add(self.version_parent)
 
         # Before reifying relations we need to reify object properties. This
